"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const highlight_js_1 = __importDefault(require("highlight.js"));
const katex_1 = __importDefault(require("katex"));
const marked_1 = __importDefault(require("marked"));
const ipynb2html_core_1 = require("ipynb2html-core");
// Removes accents from the given string.
const stripAccents = (text) => text.normalize('NFD').replace(/[\u0300-\u036f]/g, '');
// Removes math markers from the given string.
const stripMath = (text) => ipynb2html_core_1.mathExtractor.restoreMath(text, []).trim();
class Renderer extends marked_1.default.Renderer {
    heading(text, level, raw, slugger) {
        var _a;
        const opts = this.options;
        if (!opts.headerIds && !opts.headerAnchors) {
            return super.heading(text, level, raw, slugger);
        }
        let id = ((_a = opts.headerPrefix) !== null && _a !== void 0 ? _a : '') + slugger.slug(stripMath(raw));
        if (opts.headerIdsStripAccents) {
            id = stripAccents(id);
        }
        if (opts.headerAnchors) {
            text = `<a class="anchor" href="#${id}" aria-hidden="true"></a>${text}`;
        }
        return `<h${level} id="${id}">${text}</h${level}>`;
    }
    link(href, title, text) {
        return super.link(href && stripMath(href), title && stripMath(title), text);
    }
    image(href, title, text) {
        return super.image(href && stripMath(href), title && stripMath(title), stripMath(text));
    }
}
function highlight(code, lang) {
    return highlight_js_1.default.getLanguage(lang)
        ? highlight_js_1.default.highlight(lang, code, true).value
        : code;
}
const renderer = (markedOpts) => (markdown) => marked_1.default.parse(markdown, markedOpts);
const rendererWithMath = (markedOpts, katexOpts) => (markdown) => {
    const [text, math] = ipynb2html_core_1.mathExtractor.extractMath(markdown);
    const html = marked_1.default.parse(text, markedOpts);
    const mathHtml = math.map(({ value, displayMode }) => {
        return katex_1.default.renderToString(value, { ...katexOpts, displayMode });
    });
    return ipynb2html_core_1.mathExtractor.restoreMath(html, mathHtml);
};
const markdownRenderer = (markedOpts = {}, katexOpts = {}) => {
    markedOpts = { renderer: new Renderer(markedOpts), ...markedOpts };
    if (highlight_js_1.default) { // highlight.js may be an optional dependency (in browser bundle)
        markedOpts = { highlight, ...markedOpts };
    }
    return katex_1.default // katex may be an optional dependency (in browser bundle)
        ? rendererWithMath(markedOpts, katexOpts)
        : renderer(markedOpts);
};
/**
 * Returns a pre-configured marked parser with (optional) math support (using
 * KaTeX) and code highlighter (highlight.js).
 *
 * @param {MarkedOptions} markedOpts Options for the marked Markdown renderer.
 * @param {KatexOptions} katexOpts Options for the KaTeX math renderer.
 */
exports.default = markdownRenderer;
//# sourceMappingURL=markdownRenderer.js.map