"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
const marked_1 = __importDefault(require("marked"));
class EmptyRenderer extends marked_1.default.Renderer {
}
// Override all the EmptyRenderer's methods inherited from marked.Renderer to
// always return an empty string.
/* eslint-disable @typescript-eslint/no-unsafe-member-access */
const RendererProto = marked_1.default.Renderer.prototype;
for (const prop of Object.getOwnPropertyNames(RendererProto)) {
    if (prop !== 'constructor' && typeof RendererProto[prop] === 'function') {
        EmptyRenderer.prototype[prop] = () => '';
    }
}
/* eslint-enable @typescript-eslint/no-unsafe-member-access */
class MainTitleRenderer extends EmptyRenderer {
    constructor() {
        super(...arguments);
        this._titleFound = false;
    }
    heading(_text, level, raw, _slugger) {
        if (level === 1 && !this._titleFound) {
            this._titleFound = true;
            return raw;
        }
        return '';
    }
}
const readNotebookTitle = (notebook) => {
    if (notebook.metadata.title) {
        return notebook.metadata.title;
    }
    if (notebook.cells.length > 0 && notebook.cells[0].cell_type === 'markdown') {
        const source = notebook.cells[0].source;
        const markup = Array.isArray(source) ? source.join('') : source;
        return marked_1.default.parse(markup, { renderer: new MainTitleRenderer() });
    }
    return '';
};
/**
 * Returns title of the given *notebook*, or an empty string if not found.
 *
 * If the title is not present in the notebook's metadata and the first cell is
 * a Markdown cell, it parses it and returns the first level 1 heading.
 */
exports.default = readNotebookTitle;
//# sourceMappingURL=readNotebookTitle.js.map